@@ -2,18 +2,18 @@ package Mojolicious::Plugin::Util::RandomString;
 use Mojo::Base 'Mojolicious::Plugin';
 use Session::Token;
 
-our $VERSION = '0.03_3';
+our $VERSION = '0.03_4';
 
 our (%generator, %setting, %default);
 our $read_config;
-our $ok;
+our $ok = 1;
 
 # Register plugin
 sub register {
   my ($plugin, $mojo, $param) = @_;
 
   $param //= {};
-  $ok = 0;
+  $ok--;
 
   if (ref $param ne 'HASH') {
     $mojo->log->fatal(__PACKAGE__ . ' expects a hash reference');
@@ -68,7 +68,7 @@ sub register {
       # Create default generator
       unless (exists $generator{default}) {
 	$generator{default} = Session::Token->new( %default );
-	# warn $$ . ' ' . $plugin . ' Init S::T with {' . join(', ', map { $_ . ' => ' . (ref $default{$_} ? '[' . join(',', @{$default{$_}}) . ']' : $default{$_})} keys %default) . '}';
+#	warn $$ . ' ' . $plugin . ' Init S::T with {' . join(', ', map { $_ . ' => ' . (ref $default{$_} ? '[' . join(',', @{$default{$_}}) . ']' : $default{$_})} keys %default) . '}';
       };
     });
 
@@ -85,7 +85,7 @@ sub register {
     random_string => sub {
 
       # One tick for loop until the plugin is registered
-      Mojo::IOLoop->one_tick until Mojo::IOLoop->is_running || $ok;
+      Mojo::IOLoop->one_tick until Mojo::IOLoop->is_running || ($ok > 0);
 
       my $gen = $_[1];
 
